@@ -1202,7 +1202,7 @@ class Base_Page(Borg, unittest.TestCase):
         #
         # return self.gif_file_name
         if self.screenshot != 'off':
-            self.gif_file_name = Gif_Maker.make_gif(self.screenshot_dir, self.report_path, name=self.report_name)
+            self.gif_file_name = Gif_Maker.make_gif(self.screenshot_dir, self.report_path, name=self.report_name+"_"+self.calling_module)
             return self.gif_file_name
 
     def wait(self, wait_seconds=5.0, locator=None):
